@@ -36,3 +36,23 @@ def coin_or_token_frequency(coin_or_token, frequency):
         ),
     )
     return response.json(), response.status_code
+
+
+@bp.route("/charts/tether/<coin_or_token>/<frequency>", methods=["GET"])
+def tether_btc(coin_or_token, frequency):
+    response = requests.get(
+        url="{}charts/tether/{}/{}".format(
+            current_app.config["SERVER_API_BASE_URL"], coin_or_token, frequency
+        ),
+    )
+    return response.json(), response.status_code
+
+
+@bp.route("/charts/twitter", methods=["GET"])
+def twitter():
+    response = requests.get(
+        url="{}charts/twitter".format(
+            current_app.config["SERVER_API_BASE_URL"]
+        ),
+    )
+    return response.json(), response.status_code
