@@ -29,6 +29,13 @@ HISTORY_FREQUENCY = (
     "1y",
 )
 
+PRICE_CHANGE_FREQUENCIES = (
+    "1h",
+    "1d",
+    "1w",
+    "4w",
+)
+
 # exchanges settings
 from xtcryptosignals.settings_exchanges import (
     EXCHANGES,
@@ -70,4 +77,5 @@ __all__ = [
     "BILAXY",
     "TICKER_SCHEDULE",
     "HISTORY_FREQUENCY",
+    "PRICE_CHANGE_FREQUENCIES",
 ]
