@@ -33,6 +33,8 @@ CELERY_IMPORTS = (
     "xtcryptosignals.tasks.ticker",
     "xtcryptosignals.tasks.notifications",
     "xtcryptosignals.tasks.cfgi",
+    "xtcryptosignals.tasks.project",
+    "xtcryptosignals.tasks.tether",
 )
 
 CELERYBEAT_SCHEDULE = {
@@ -48,4 +50,12 @@ CELERYBEAT_SCHEDULE = {
         "task": "xtcryptosignals.tasks.cfgi.update",
         "schedule": crontab(hour=5, minute=30),
     },
+    "project": {
+        "task": "xtcryptosignals.tasks.project.update",
+        "schedule": crontab(hour=23, minute=59),
+    },
+    "tether": {
+        "task": "xtcryptosignals.tasks.tether.update",
+        "schedule": crontab(hour="*", minute=1),
+    },
 }
