@@ -8,9 +8,9 @@ __maintainer__ = "Paulo Antunes"
 __email__ = "pjmlantunes@gmail.com"
 
 
-from xtcryptosignals.tasks import settings as s
 from binance.client import Client
 from binance.exceptions import BinanceAPIException
+from xtcryptosignals.tasks import settings as s
 
 
 class Binance:
@@ -34,7 +34,7 @@ class Binance:
             item.update(ticker=symbol[0])
             return item
 
-        items = list()
+        items = []
         pairs = [x[0] + x[1] for x in kwargs["pairs"]]
         for item in items_or_item:
             if item["symbol"] in pairs:
