@@ -13,8 +13,9 @@ import requests
 
 class Okcoin:
     def __init__(self):
-        self.base_url = "https://www.okcoin.com/api/spot/v3/" \
-                        "instruments/{}-{}/ticker"
+        self.base_url = (
+            "https://www.okcoin.com/api/spot/v3/instruments/{}-{}/ticker"
+        )
 
     def get_ticker(self, symbol):
         url = self.base_url.format(*symbol)
