@@ -29,7 +29,7 @@ TIMEOUT_PER_SYMBOLS_REQUEST = 5.0  # in seconds
 SYMBOL_FLOAT_PRECISION = 8
 PRICES_CHANGE_CHART_SIZE = 12
 
-REDIS_KEY_TICKER = "{source}_{symbol}_price"
+REDIS_KEY_TICKER = "{source}_{symbol}_{frequency}_price"
 REDIS_CFGI = "cfgi"
 
 URL_CFGI = "https://api.alternative.me/fng"
@@ -37,6 +37,8 @@ URL_CFGI = "https://api.alternative.me/fng"
 VAPID_CLAIMS = env.str("VAPID_CLAIMS")
 VAPID_PRIVATE_KEY = env.str("VAPID_PRIVATE_KEY")
 
+ETHERSCAN_API_KEY = env.str("ETHERSCAN_API_KEY")
+
 STATIC_COINS_TOKENS_LOGOS_FOLDER = "/static/imgs/logos/"
 
 from xtcryptosignals.settings import *  # noqa
